# standard imports
import logging

# external imports
from chainlib.chain import ChainSpec
from chainlib.eth.tx import TxFormat
from chainlib.eth.connection import RPCConnection
from eth_token_index import TokenUniqueSymbolIndex

logg = logging.getLogger(__name__)


class CICEth:

    def __init__(self, chain_spec, resources, proofs, signer=None, rpc=None, nonce_oracle=None, fee_oracle=None):
        self.resources = resources
        self.proofs = proofs
        self.chain_spec = chain_spec
        self.signer = signer
        self.rpc = rpc
        self.nonce_oracle = nonce_oracle
        self.fee_oracle = fee_oracle
        self.token_address = None
        self.outputs = {}
        for k in resources.keys():
            self.outputs[k] = None
        self.tx_format = TxFormat.RLP_SIGNED
        if self.signer == None:
            self.tx_format = TxFormat.RAW_ARGS


    def process_token(self):
        raise NotImplementedError


    def process_token_index(self):
        c = TokenUniqueSymbolIndex(self.chain_spec, signer=self.signer) #        tx_format = None

        contract_address = self.resources['token_index']['reference']
        signer_address = self.resources['token_index']['key_address']
        o = c.register(contract_address, signer_address, self.token_address, tx_format=self.tx_format)
        if self.rpc != None:
            pass
        elif self.signer != None:
            self.outputs['token_index'] = o[1]
        else:
            self.outputs['token_index'] = o
        

    def process(self):
        self.token_address = self.resources['token']['reference']
        if self.token_address == None:
            tasks.append('token')
        tasks.append('token_index')
        for task in tasks:
            getattr(self, 'process_̈́ ' + task)()


def new(resources, proofs, signer_hint=None):
    return CICEth(resources, proofs, signer=None)
